@@ -29,11 +29,7 @@ class KCMCron : public KCModule
     Q_OBJECT
 
 public:
-#if QT_VERSION_MAJOR == 5
-    KCMCron(QWidget *parent, const QVariantList &args);
-#else
     KCMCron(QObject *parent);
-#endif
 
     ~KCMCron() override;
 
